@@ -10,6 +10,6 @@
 
 G_BEGIN_DECLS
 
-const char * gm_mcc_to_iso (const char *mcc_str, GError **err);
+const char * gm_mcc_to_iso (const char *mcc, GError **err);
 
 G_END_DECLS
